=============================
Cell assembly detection (CAD)
=============================

.. automodule:: elephant.cell_assembly_detection


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: cad
   :keyprefix: cad-
   :style: unsrt
